Documentation
¶
Index ¶
- Variables
- func AsBigFloat(src any) (*big.Float, error)
- func AsBool(src any) (bool, error)
- func AsBytes(src any) ([]byte, bool)
- func AsFloat64(src any) (float64, error)
- func AsInt64(src any) (int64, error)
- func AsString(src any) string
- func AsTime(src any, dbLoc, uiLoc *time.Location) (*time.Time, error)
- func AsUint64(src any) (uint64, error)
- func Assign(dest, src any, originalLocation, convertedLocation *time.Location) error
- func AssignValue(dv reflect.Value, src any) error
- func Interface2Interface(userLocation *time.Location, v any) (any, error)
- func String2Time(s string, originalLocation, convertedLocation *time.Location) (*time.Time, error)
- type Conversion
- type ConversionFrom
- type ConversionTo
- type EmptyScanner
- type NullUint32
- type NullUint64
Constants ¶
This section is empty.
Variables ¶
var ErrNilPtr = errors.New("destination pointer is nil") // embedded in descriptive error
ErrNilPtr represents an error
Functions ¶
func AsBigFloat ¶
AsBigFloat converts interface as big.Float
func Assign ¶
Assign copies to dest the value in src, converting it if possible. An error is returned if the copy would result in loss of information. dest should be a pointer type.
func Interface2Interface ¶
Interface2Interface converts interface of pointer as interface of value
Types ¶
type Conversion ¶
type Conversion interface {
ConversionFrom
ConversionTo
}
Conversion is an interface. A type implements Conversion will according the custom method to fill into database and retrieve from database.
type ConversionFrom ¶
ConversionFrom is an inteface to allow retrieve data from database
type ConversionTo ¶
ConversionTo is an interface to allow store data to database
type EmptyScanner ¶
type EmptyScanner struct{}
EmptyScanner represents an empty scanner which will ignore the scan
type NullUint32 ¶
NullUint32 represents an uint32 that may be null. NullUint32 implements the Scanner interface so it can be used as a scan destination, similar to NullString.
func (*NullUint32) Scan ¶
func (n *NullUint32) Scan(value any) error
Scan implements the Scanner interface.
type NullUint64 ¶
NullUint64 represents an uint64 that may be null. NullUint64 implements the Scanner interface so it can be used as a scan destination, similar to NullString.
func (*NullUint64) Scan ¶
func (n *NullUint64) Scan(value any) error
Scan implements the Scanner interface.